import { join } from 'path';
import chalk from 'chalk';
import React from 'react';
import helmet from 'helmet';
import express from 'express';
import { info } from 'winston';
import reactViews from 'express-react-views';
import compression from 'compression';
import { renderToString } from 'react-dom/server';
import { match, RouterContext } from 'react-router';

import routes from './shared/routes';

export const app = express();

app.set('port', process.env.PORT || 3001);
app.set('views', join(__dirname, 'views'));
app.set('view engine', 'jsx');

app.engine('jsx', reactViews.createEngine());

app.use(helmet());
app.use(compression());
app.use('/dist', express.static(join(__dirname, 'dist')));

app.use((req, res, next) => {
  match({ routes, location: req.url }, (err, redirectUrl, renderProps) => {
    return err ? next(err)
    : redirectUrl ? res.redirect(302, redirectUrl.pathname + redirectUrl.search)
    : renderProps ? res.status(200).render('layout', { tree: renderToString(<RouterContext {...renderProps} />) })
    : res.redirect(302, '/') // catch-all
  })
})

app.use((err, req, res, next) => {
  info(chalk.red.bold(err));
})
