import { Base } from 'yeoman-generator';
import humanizeUrl from 'humanize-url';
import { kebabCase } from 'lodash/string';

module.exports = class Ua extends Base {
  init() {
    return this.prompt([{
      name: 'appName',
      message: 'What is the name of the app?',
      default: kebabCase(this.appname),
      filter: name => kebabCase(name)
    }, {
      name: 'appDescription',
      message: 'How would you describe it?',
      default: 'a universal experiment',
      validate: desc => desc.length ? true : ''
    }, {
      name: 'githubUsername',
      message: 'What is your github username?',
      store: true,
      validate: name => name.length ? true : ''
    }, {
      name: 'website',
      message: 'What is your website\'s URL?',
      store: true,
      validate: url => url.length ? true : ''
    }])
      .then((props) => {
        this.fs.copyTpl([`${this.templatePath()}/**`], this.destinationPath(), {
          appName: props.appName,
          appDescription: props.appDescription,
          githubUsername: props.githubUsername,
          website: humanizeUrl(props.website),
          name: this.user.git.name(),
          email: this.user.git.email()
        })

        const mv = (x, y) => this.fs.move(this.destinationPath(x), this.destinationPath(y));

        // unaugment augmented filenames
        mv('eslintrc', '.eslintrc');
        mv('gitignore', '.gitignore');
        mv('travis.yml', '.travis.yml');
        mv('_package.json', 'package.json');
      })
      .catch(err => console.error(err))
  }

  git() {
    this.spawnCommandSync('git', ['init']);
  }

  install() {
    this.installDependencies({
      bower: false,
      callback: () => this.spawnCommandSync('npm', ['run', 'dev'])
    })
  }
}
